@@ -1,4 +1,4 @@
-test_that("raster_to_raw runs without errors", {
+test_that("raster_to_raw warns about deprecation", {
   # on GitHub, this test fails to find temp files used in the middle of
   # raster_to_raw on windows and mac devices
   #
@@ -7,21 +7,23 @@ test_that("raster_to_raw runs without errors", {
   # GH environment rather than using magick to open a tempfile.
   skip_on_os(c("windows", "mac"))
   skip_on_cran()
-  expect_error(
+
+  expect_warning(
     raster_to_raw_tiles(
       input_file = "testdata/merge_rasters_test.tif",
       output_prefix = tempfile(),
       side_length = 4097,
-      raw = TRUE
-    ),
-    NA
+      raw = FALSE
+    )
   )
 
-  outputs <- raster_to_raw_tiles(
-    input_file = "testdata/merge_rasters_test.tif",
-    output_prefix = tempfile(),
-    side_length = 4097,
-    raw = FALSE
+  outputs <- suppressWarnings(
+    raster_to_raw_tiles(
+      input_file = "testdata/merge_rasters_test.tif",
+      output_prefix = tempfile(),
+      side_length = 4097,
+      raw = FALSE
+    )
   )
 
   expect_equal(
