@@ -1,11 +1,14 @@
 test_that("get_tiles gets the same ortho tiles twice", {
   skip_on_cran()
-  output_tif <- get_tiles(list(
-    c(lat = 44.04905, lng = -74.01188),
-    c(lat = 44.04911, lng = -74.01179)
-  ),
-  services = c("ortho", "USGSNAIPPlus"),
-  georeference = FALSE
+  dl_loc <- data.frame(
+    lat = c(44.04905, 44.04911),
+    lng = c(-74.01188, -74.01179)
+  )
+  dl_loc <- sf::st_as_sf(dl_loc, coords = c("lng", "lat"))
+  sf::st_crs(dl_loc) <- sf::st_crs(4326)
+  output_tif <- get_tiles(dl_loc,
+    services = c("ortho", "USGSNAIPPlus"),
+    georeference = FALSE
   )
 
   expect_equal(names(output_tif), "ortho")
@@ -15,24 +18,26 @@ test_that("get_tiles gets the same ortho tiles twice", {
 
   expect_equal(
     png::readPNG(output_tif[[1]]),
-    png::readPNG("testdata/NAIPPlus.png")
+    png::readPNG("testdata/NewNAIPPlus.png")
   )
 })
 
 test_that("get_tiles gets the same georeferenced ortho tiles twice", {
   skip_on_cran()
-  skip_on_travis() # for now
-  output_tif <- get_tiles(list(
-    c(lat = 44.04905, lng = -74.01188),
-    c(lat = 44.04911, lng = -74.01179)
-  ),
-  services = c("ortho", "USGSNAIPPlus")
+  dl_loc <- data.frame(
+    lat = c(44.04905, 44.04911),
+    lng = c(-74.01188, -74.01179)
+  )
+  dl_loc <- sf::st_as_sf(dl_loc, coords = c("lng", "lat"))
+  sf::st_crs(dl_loc) <- sf::st_crs(4326)
+  output_tif <- get_tiles(dl_loc,
+    services = c("ortho", "USGSNAIPPlus")
   )
 
   expect_equal(length(output_tif), 1)
   expect_equal(length(output_tif[[1]]), 1)
 
-  stored_raster <- raster::raster("testdata/NAIPPlus_gr.tif")
+  stored_raster <- raster::raster("testdata/NewNAIPPlus_gr.tif")
   test_raster <- raster::raster(output_tif[[1]])
 
   expect_equal(stored_raster@crs, test_raster@crs)
